pub struct SpatializedNormalCone<N: RealField + Copy> {
pub aabb: AABB<N>,
pub normals: CircularCone<N>,
}Expand description
The combination of an AABB with a circular cone to bound both the space occupied by an geometry and its normals.
Fields
aabb: AABB<N>An AABB bounding the space occupied by a geometry.
normals: CircularCone<N>A circular cone bounding the normals of a geometry.