pub enum BestFirstVisitStatus<N, Res> {
Continue {
cost: N,
result: Option<Res>,
},
Stop,
ExitEarly(Option<Res>),
}Expand description
The next action to be taken by a BVH traversal algorithm after having visited a node with some data.
Variants
Continue
The traversal continues recursively, associating the given cost to the visited node and some associated result.
Fields

cost: NThe cost associated to this node.
Stop
The traversal does not continue recursively on the visited node’s children.
ExitEarly(Option<Res>)
The traversal aborts.
If a data is provided, then it is returned as the result of the traversal. If no result is provided, then the last best result found becomes the result of the traversal.