pub struct CollisionObjectUpdateFlags(/* private fields */);Expand description
Flags indicating what changed in a collision object since the last collision world update.
Implementations
Sourceimpl CollisionObjectUpdateFlags
impl CollisionObjectUpdateFlags
Sourcepub const POSITION_CHANGED: Self
pub const POSITION_CHANGED: Self
Indicate that the collision object’s position changed.
Sourcepub const PREDICTED_POSITION_CHANGED: Self
pub const PREDICTED_POSITION_CHANGED: Self
Indicate that the collision object’s predicted position changed.
Sourcepub const SHAPE_CHANGED: Self
pub const SHAPE_CHANGED: Self
Indicate that the collision object’s shape changed.
Sourcepub const COLLISION_GROUPS_CHANGED: Self
pub const COLLISION_GROUPS_CHANGED: Self
Indicate that the collision object’s collision group changed.
Sourcepub const QUERY_TYPE_CHANGED: Self
pub const QUERY_TYPE_CHANGED: Self
Indicate that the collision object’s geometric query type changed.
Sourceimpl CollisionObjectUpdateFlags
impl CollisionObjectUpdateFlags
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<Self>
pub const fn from_bits(bits: u8) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> Self
pub const fn from_bits_truncate(bits: u8) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> Self
pub const fn from_bits_retain(bits: u8) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl CollisionObjectUpdateFlags
impl CollisionObjectUpdateFlags
Sourcepub const fn iter(&self) -> Iter<CollisionObjectUpdateFlags>
pub const fn iter(&self) -> Iter<CollisionObjectUpdateFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<CollisionObjectUpdateFlags>
pub const fn iter_names(&self) -> IterNames<CollisionObjectUpdateFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl CollisionObjectUpdateFlags
impl CollisionObjectUpdateFlags
Sourcepub fn needs_broad_phase_update(&self) -> bool
pub fn needs_broad_phase_update(&self) -> bool
Checks if the collision object has been changed in a way that justify a broad-phase update.
Sourcepub fn needs_narrow_phase_update(&self) -> bool
pub fn needs_narrow_phase_update(&self) -> bool
Checks if the collision object has been changed in a way that justify a narrow-phase update.
Sourcepub fn needs_bounding_volume_update(&self) -> bool
pub fn needs_bounding_volume_update(&self) -> bool
Checks if the collision object has been changed in a way that justify an update of its bounding volume.
Sourcepub fn needs_broad_phase_redispatch(&self) -> bool
pub fn needs_broad_phase_redispatch(&self) -> bool
Checks if the collision object has been changed in a way that justify that the broad-phase recompute all potential proximity pairs for this collision objects.