pub struct VoronoiSimplex<N: RealField + Copy> { /* private fields */ }Expand description
A simplex of dimension up to 2 using Voronoï regions for computing point projections.
Implementations
Sourceimpl<N: RealField + Copy> VoronoiSimplex<N>
impl<N: RealField + Copy> VoronoiSimplex<N>
Sourcepub fn new() -> VoronoiSimplex<N>
pub fn new() -> VoronoiSimplex<N>
Crates a new empty simplex.
Sourcepub fn proj_coord(&self, i: usize) -> N
pub fn proj_coord(&self, i: usize) -> N
Retrieves the barycentric coordinate associated to the i-th by the last call to project_origin_and_reduce.
Sourcepub fn prev_proj_coord(&self, i: usize) -> N
pub fn prev_proj_coord(&self, i: usize) -> N
Retrieves the barycentric coordinate associated to the i-th before the last call to project_origin_and_reduce.
Sourcepub fn prev_point(&self, i: usize) -> &CSOPoint<N>
pub fn prev_point(&self, i: usize) -> &CSOPoint<N>
The i-th point of the simplex before the last call to projet_origin_and_reduce.
Sourcepub fn project_origin_and_reduce(&mut self) -> Point<N>
pub fn project_origin_and_reduce(&mut self) -> Point<N>
Projets the origin on the boundary of this simplex and reduces self the smallest subsimplex containing the origin.
Retruns the result of the projection or Point::origin() if the origin lies inside of the simplex.
The state of the samplex before projection is saved, and can be retrieved using the methods prefixed
by prev_.
Sourcepub fn project_origin(&mut self) -> Point<N>
pub fn project_origin(&mut self) -> Point<N>
Compute the projection of the origin on the boundary of this simplex.
Sourcepub fn contains_point(&self, pt: &Point<N>) -> bool
pub fn contains_point(&self, pt: &Point<N>) -> bool
Tests if the given point is already a vertex of this simplex.
Sourcepub fn dimension(&self) -> usize
pub fn dimension(&self) -> usize
The dimension of the smallest subspace that can contain this simplex.
Sourcepub fn prev_dimension(&self) -> usize
pub fn prev_dimension(&self) -> usize
The dimension of the simplex before the last call to project_origin_and_reduce.
Sourcepub fn max_sq_len(&self) -> N
pub fn max_sq_len(&self) -> N
The maximum squared length of the vertices of this simplex.
Sourcepub fn modify_pnts(&mut self, f: &dyn Fn(&mut CSOPoint<N>))
pub fn modify_pnts(&mut self, f: &dyn Fn(&mut CSOPoint<N>))
Apply a function to all the vertices of this simplex.