FeatureId

Enum FeatureId 

pub enum FeatureId {
    Vertex(usize),
    Face(usize),
    Unknown,
}
An identifier of a feature of a convex polyhedron.

This identifier is shape-dependent and is seach that it allows an efficient retrieval of the geometric information of the feature.

Variants



Vertex(usize)

Shape-dependent identifier of a vertex.



Face(usize)

Shape-dependent identifier of a face.



Unknown

Unknown identifier.

Implementations

Source

impl FeatureId

pub fn unwrap_vertex(self) -> usize

Revries the value of the identifier if self is a vertex.

pub fn unwrap_face(self) -> usize

Retrieves the value of the identifier if self is a face.