pub enum TrianglePointLocation<N: RealField + Copy> {
OnVertex(usize),
OnEdge(usize, [N; 2]),
OnFace(usize, [N; 3]),
OnSolid,
}Expand description
Description of the location of a point on a triangle.
Variants
OnVertex(usize)
The point lies on a vertex.
OnEdge(usize, [N; 2])
The point lies on an edge.
The 0-st edge is the segment AB. The 1-st edge is the segment BC. The 2-nd edge is the segment AC.
OnFace(usize, [N; 3])
The point lies on the triangle interior.
The integer indicates on which side of the face the point is. 0 indicates the point is on the half-space toward the CW normal of the triangle. 1 indicates the point is on the other half-space. This is always set to 0 in 2D.
OnSolid
The point lies on the triangle interior (for “solid” point queries).
Implementations
Sourceimpl<N: RealField + Copy> TrianglePointLocation<N>
impl<N: RealField + Copy> TrianglePointLocation<N>
Sourcepub fn barycentric_coordinates(&self) -> Option<[N; 3]>
pub fn barycentric_coordinates(&self) -> Option<[N; 3]>
The barycentric coordinates corresponding to this point location.
Returns None if the location is TrianglePointLocation::OnSolid.
Sourcepub fn is_on_face(&self) -> bool
pub fn is_on_face(&self) -> bool
Returns true if the point is located on the relative interior of the triangle.