HeightField

Struct HeightField 

pub struct HeightField<N: RealField + Copy> { /* private fields */ }
A 2D heightfield.

Implementations

Source

impl<N: RealField + Copy> HeightField<N>

pub fn new(heights: DVector<N>, scale: Vector<N>) -> Self

Creates a new 2D heightfield with the given heights and scale factor.

pub fn num_cells(&self) -> usize

The number of cells of this heightfield.

pub fn heights(&self) -> &DVector<N>

The height at each cell endpoint.

pub fn scale(&self) -> &Vector<N>

The scale factor applied to this heightfield.

pub fn aabb(&self) -> &AABB<N>

The AABB of this heightfield.

pub fn cell_width(&self) -> N

The width of a single cell of this heightfield.

pub fn unit_cell_width(&self) -> N

The width of a single cell of this heightfield, without taking the scale factor into account.

pub fn start_x(&self) -> N

The left-most x-coordinate of this heightfield.

pub fn cell_at_point(&self, pt: &Point2<N>) -> Option<usize>

Index of the cell a point is on after vertical projection.

pub fn segments<'a>(&'a self) -> impl Iterator<Item = Segment<N>> + 'a

Iterator through all the segments of this heightfield.

pub fn segment_at(&self, i: usize) -> Option<Segment<N>>

The i-th segment of the heightfield if it has not been removed.

pub fn set_segment_removed(&mut self, i: usize, removed: bool)

Mark the i-th segment of this heightfield as removed or not.

pub fn is_segment_removed(&self, i: usize) -> bool

Checks if the i-th segment has been removed.

pub fn map_elements_in_local_aabb( &self, aabb: &AABB<N>, f: &mut impl FnMut(usize, &Segment<N>, &dyn ContactPreprocessor<N>), )

Applies f to each segment of this heightfield that intersects the given aabb.