ShapeHandle

Struct ShapeHandle 

pub struct ShapeHandle<N: RealField + Copy>(/* private fields */);
A shared handle to an abstract shape.

This can be mutated using COW.

Implementations

Source

impl<N: RealField + Copy> ShapeHandle<N>

pub fn new<S: Shape<N>>(shape: S) -> ShapeHandle<N>

Creates a sharable shape handle from a shape.

pub fn from_arc(shape: Arc<dyn Shape<N>>) -> ShapeHandle<N>

Creates a sharable shape handle from a shape trait object.

pub fn as_arc(&self) -> &Arc<dyn Shape<N>>

Gets a reference the Arc refcounted shape object.

Methods from Deref<Target = dyn Shape<N>>

pub fn is<__T: Shape<N>>(&self) -> bool

Returns true if the trait object wraps an object of type __T.

pub fn downcast_rc<__T: Shape<N>>(self: Rc<Self>) -> Result<Rc<__T>, Rc<Self>>

Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of type __T. Returns the original Rc-ed trait if it isn’t.

pub fn downcast_ref<__T: Shape<N>>(&self) -> Option<&__T>

Returns a reference to the object within the trait object if it is of type __T, or None if it isn’t.

pub fn is_shape<T: Shape<N>>(&self) -> bool

Tests if this shape has a specific type T.

pub fn as_shape<T: Shape<N>>(&self) -> Option<&T>

Performs the cast.