#[repr(C)]pub struct Triangle<N: RealField + Copy> {
pub a: Point<N>,
pub b: Point<N>,
pub c: Point<N>,
}Expand description
A triangle shape.
Fields
a: Point<N>The triangle first point.
b: Point<N>The triangle second point.
c: Point<N>The triangle third point.
Implementations
Sourceimpl<N: RealField + Copy> Triangle<N>
impl<N: RealField + Copy> Triangle<N>
Sourcepub fn new(a: Point<N>, b: Point<N>, c: Point<N>) -> Triangle<N>
pub fn new(a: Point<N>, b: Point<N>, c: Point<N>) -> Triangle<N>
Creates a triangle from three points.
Sourcepub fn from_array(arr: &[Point<N>; 3]) -> &Triangle<N>
pub fn from_array(arr: &[Point<N>; 3]) -> &Triangle<N>
Creates the reference to a triangle from the reference to an array of three points.
Sourcepub fn a(&self) -> &Point<N>
👎Deprecated: use the self.a public field directly.
pub fn a(&self) -> &Point<N>
self.a public field directly.The fist point of this triangle.
Sourcepub fn b(&self) -> &Point<N>
👎Deprecated: use the self.b public field directly.
pub fn b(&self) -> &Point<N>
self.b public field directly.The second point of this triangle.
Sourcepub fn c(&self) -> &Point<N>
👎Deprecated: use the self.c public field directly.
pub fn c(&self) -> &Point<N>
self.c public field directly.The third point of this triangle.
Sourcepub fn vertices(&self) -> &[Point<N>; 3]
pub fn vertices(&self) -> &[Point<N>; 3]
Reference to an array containing the three vertices of this triangle.
Sourcepub fn normal(&self) -> Option<Unit<Vector<N>>>
pub fn normal(&self) -> Option<Unit<Vector<N>>>
The normal of this triangle assuming it is oriented ccw.
The normal points such that it is collinear to AB × AC (where × denotes the cross
product).
Sourcepub fn transformed(&self, m: &Isometry<N>) -> Self
pub fn transformed(&self, m: &Isometry<N>) -> Self
Returns a new triangle with vertices transformed by m.
Sourcepub fn edges_scaled_directions(&self) -> [Vector<N>; 3]
pub fn edges_scaled_directions(&self) -> [Vector<N>; 3]
The three edges scaled directions of this triangle: [B - A, C - B, A - C].
Sourcepub fn scaled_normal(&self) -> Vector<N>
pub fn scaled_normal(&self) -> Vector<N>
A vector normal of this triangle.
The vector points such that it is collinear to AB × AC (where × denotes the cross
product).
Sourcepub fn extents_on_dir(&self, dir: &Unit<Vector<N>>) -> (N, N)
pub fn extents_on_dir(&self, dir: &Unit<Vector<N>>) -> (N, N)
Computes the extents of this triangle on the given direction.
This computes the min and max values of the dot products between each
vertex of this triangle and dir.